@@ -77,13 +77,6 @@
 
 #if @GNULIB_RANDOM_R@
 
-/* OSF/1 5.1 declares 'struct random_data' in <random.h>, which is included
-   from <stdlib.h> if _REENTRANT is defined.  Include it whenever we need
-   'struct random_data'.  */
-# if @HAVE_RANDOM_H@
-#  include <random.h>
-# endif
-
 # include <stdint.h>
 
 # if !@HAVE_STRUCT_RANDOM_DATA@
