@@ -80,6 +80,12 @@
 # include <strings.h>
 #endif
 
+_GL_INLINE_HEADER_BEGIN
+
+#ifndef _GL_STRING_INLINE
+# define _GL_STRING_INLINE _GL_INLINE
+#endif
+
 /* _GL_ATTRIBUTE_DEALLOC (F, I) declares that the function returns pointers
    that can be freed by passing them as the Ith argument to the
    function F.  */
@@ -409,6 +415,21 @@ _GL_WARN_ON_USE (memchr, "memchr has platform-specific bugs - "
                  "use gnulib module memchr for portability" );
 #endif
 
+/* Are S1 and S2, of size N, bytewise equal?  */
+#if @GNULIB_STRINGEQ@ && !@HAVE_DECL_MEMEQ@
+# ifdef __cplusplus
+extern "C" {
+# endif
+_GL_STRING_INLINE bool
+memeq (void const *__s1, void const *__s2, size_t __n)
+{
+  return !memcmp (__s1, __s2, __n);
+}
+# ifdef __cplusplus
+}
+# endif
+#endif
+
 /* Return the first occurrence of NEEDLE in HAYSTACK.  */
 #if @GNULIB_MEMMEM@
 # if @REPLACE_MEMMEM@
@@ -789,6 +810,21 @@ _GL_CXXALIASWARN (strdup);
 # endif
 #endif
 
+/* Are strings S1 and S2 equal?  */
+#if @GNULIB_STRINGEQ@ && !@HAVE_DECL_STREQ@
+# ifdef __cplusplus
+extern "C" {
+# endif
+_GL_STRING_INLINE bool
+streq (char const *__s1, char const *__s2)
+{
+  return !strcmp (__s1, __s2);
+}
+# ifdef __cplusplus
+}
+# endif
+#endif
+
 /* Append no more than N characters from SRC onto DEST.  */
 #if @GNULIB_STRNCAT@
 # if @REPLACE_STRNCAT@
@@ -1208,7 +1244,7 @@ _GL_EXTERN_C bool str_endswith (const char *string, const char *prefix)
 # ifdef __MirBSD__  /* MirBSD defines mbslen as a macro.  Override it.  */
 #  undef mbslen
 # endif
-# if @HAVE_MBSLEN@  /* AIX, OSF/1, MirBSD define mbslen already in libc.  */
+# if @HAVE_MBSLEN@  /* AIX, MirBSD define mbslen already in libc.  */
 #  if !(defined __cplusplus && defined GNULIB_NAMESPACE)
 #   define mbslen rpl_mbslen
 #  endif
@@ -1722,6 +1758,7 @@ _GL_WARN_ON_USE (strverscmp, "strverscmp is unportable - "
 # endif
 #endif
 
+_GL_INLINE_HEADER_END
 
 #endif /* _@GUARD_PREFIX@_STRING_H */
 #endif /* _@GUARD_PREFIX@_STRING_H */
