@@ -15,7 +15,7 @@
  *   See the GNU General Public License for more details.                 *
  *                                                                        *
  *   You should have received a copy of the GNU General Public License    *
- *   along with this program.  If not, see http://www.gnu.org/licenses/.  *
+ *   along with this program.  If not, see https://gnu.org/licenses/.     *
  *                                                                        *
  **************************************************************************/
 
@@ -1022,10 +1022,15 @@ void execute_command(const char *command)
 		/* Original and temporary handlers for SIGINT. */
 	ssize_t was_lineno = (openfile->mark ? 0 : openfile->current->lineno);
 	int command_status, sender_status;
+	bool capture_output = TRUE;
 	FILE *stream;
 
 	should_pipe = (command[0] == '|');
 
+	/* Two leading pipe symbols mean: let the output go to the terminal. */
+	if (should_pipe && command[1] == '|')
+		capture_output = FALSE;
+
 	/* Create a pipe to read the command's output from, and, if needed,
 	 * a pipe to feed the command's input through. */
 	if (pipe(from_fd) == -1 || (should_pipe && pipe(to_fd) == -1)) {
@@ -1044,7 +1049,7 @@ void execute_command(const char *command)
 		close(from_fd[0]);
 
 		/* Connect the write end of the output pipe to the process' output streams. */
-		if (dup2(from_fd[1], STDOUT_FILENO) < 0)
+		if (capture_output && dup2(from_fd[1], STDOUT_FILENO) < 0)
 			exit(3);
 		if (dup2(from_fd[1], STDERR_FILENO) < 0)
 			exit(4);
@@ -1059,7 +1064,8 @@ void execute_command(const char *command)
 		}
 
 		/* Run the given command inside the preferred shell. */
-		execl(theshell, tail(theshell), "-c", should_pipe ? &command[1] : command, NULL);
+		execl(theshell, tail(theshell), "-c", should_pipe ? capture_output ?
+										&command[1] : &command[2] : command, NULL);
 
 		/* If the exec call returns, there was an error. */
 		exit(6);
@@ -1342,12 +1348,10 @@ void insert_a_file_or(bool execute)
 			if (ISSET(MULTIBUFFER)) {
 #ifdef ENABLE_HISTORIES
 				if (ISSET(POSITIONLOG)) {
-					ssize_t priorline, priorcol;
 #ifndef NANO_TINY
 					if (!execute)
 #endif
-					if (has_old_position(answer, &priorline, &priorcol))
-						goto_line_and_column(priorline, priorcol, FALSE, FALSE);
+						restore_cursor_position_if_any();
 				}
 #endif
 				/* Update title bar and color info for this new buffer. */
@@ -1557,10 +1561,10 @@ void init_backup_dir(void)
 }
 #endif
 
-/* Read all data from inn, and write it to out.  File inn must be open for
- * reading, and out for writing.  Return 0 on success, a negative number on
- * read error, and a positive number on write error.  File inn is always
- * closed by this function, out is closed  only if close_out is true. */
+/* Read all data from `inn`, and write it to `out`.  File `inn` must be open
+ * for reading, and `out` for writing.  Return 0 on success, a negative number
+ * on read error, and a positive number on write error.  File `inn` is always
+ * closed by this function, `out` is closed only if `close_out` is true. */
 int copy_file(FILE *inn, FILE *out, bool close_out)
 {
 	int retval = 0;
@@ -2195,6 +2199,7 @@ int write_it_out(bool exiting, bool withprompt)
 
 		/* Upon request, abandon the buffer. */
 		if (function == discard_buffer) {
+			final_status = 2;  /* ^O^Q makes nano exit with an error. */
 			free(given);
 			return 2;
 		}
