@@ -15,7 +15,7 @@
  *   See the GNU General Public License for more details.                 *
  *                                                                        *
  *   You should have received a copy of the GNU General Public License    *
- *   along with this program.  If not, see http://www.gnu.org/licenses/.  *
+ *   along with this program.  If not, see https://gnu.org/licenses/.     *
  *                                                                        *
  **************************************************************************/
 
@@ -260,7 +260,7 @@ void finish(void)
 #endif
 
 	/* Get out. */
-	exit(0);
+	exit(final_status);
 }
 
 /* Close the current buffer, and terminate nano if it is the only buffer. */
@@ -271,7 +271,7 @@ void close_and_go(void)
 		delete_lockfile(openfile->lock_filename);
 #endif
 #ifdef ENABLE_HISTORIES
-	if (ISSET(POSITIONLOG))
+	if (ISSET(POSITIONLOG) && openfile->filename[0] != '\0')
 		update_poshistory();
 #endif
 #ifdef ENABLE_MULTIBUFFER
@@ -901,10 +901,21 @@ bool scoop_stdin(void)
 
 	return TRUE;
 }
-#endif
 
-/* Register half a dozen signal handlers. */
-void signal_init(void)
+/* Register a handler for SIGWINCH because we want to handle window resizes. */
+void set_up_sigwinch_handler(void)
+{
+#ifdef SIGWINCH
+	struct sigaction deed = {{0}};
+
+	deed.sa_handler = handle_sigwinch;
+	sigaction(SIGWINCH, &deed, NULL);
+#endif
+}
+#endif /* !NANO_TINY */
+
+/* Register five more signal handlers. */
+void set_up_signal_handlers(void)
 {
 	struct sigaction deed = {{0}};
 
@@ -922,19 +933,12 @@ void signal_init(void)
 #endif
 	sigaction(SIGTERM, &deed, NULL);
 
-#ifndef NANO_TINY
-#ifdef SIGWINCH
-	/* Trap SIGWINCH because we want to handle window resizes. */
-	deed.sa_handler = handle_sigwinch;
-	sigaction(SIGWINCH, &deed, NULL);
-#endif
-#ifdef SIGTSTP
+#if defined(SIGTSTP) && !defined(NANO_TINY)
 	/* Prevent the suspend handler from getting interrupted. */
 	sigfillset(&deed.sa_mask);
 	deed.sa_handler = suspend_nano;
 	sigaction(SIGTSTP, &deed, NULL);
 #endif
-#endif /* !NANO_TINY */
 #ifdef SIGCONT
 	sigfillset(&deed.sa_mask);
 	deed.sa_handler = continue_nano;
@@ -1035,11 +1039,6 @@ void block_sigwinch(bool blockit)
 	sigaddset(&winch, SIGWINCH);
 	sigprocmask(blockit ? SIG_BLOCK : SIG_UNBLOCK, &winch, NULL);
 #endif
-
-#ifndef NANO_TINY
-	if (the_window_resized)
-		regenerate_screen();
-#endif
 }
 #endif
 
@@ -1049,6 +1048,7 @@ void handle_sigwinch(int signal)
 {
 	/* Let the input routine know that a SIGWINCH has occurred. */
 	the_window_resized = TRUE;
+	resized_for_browser = TRUE;
 }
 
 /* Reinitialize and redraw the screen completely. */
@@ -1072,11 +1072,10 @@ void regenerate_screen(void)
 	terminal_init();
 	window_init();
 
-	/* If we have an open buffer, redraw the contents of the subwindows. */
-	if (openfile) {
+	/* Only when fully initialized, redraw the contents of the subwindows. */
+	if (we_are_running) {
 		ensure_firstcolumn_is_aligned();
-		if (currmenu & ~(MBROWSER|MWHEREISFILE|MGOTODIR))
-			draw_all_subwindows();
+		draw_all_subwindows();
 	}
 }
 
@@ -1832,6 +1831,7 @@ int main(int argc, char **argv)
 		{"indicator", 0, NULL, 'q'},
 		{"unix", 0, NULL, 'u'},
 		{"afterends", 0, NULL, 'y'},
+		{"whitespacedisplay", 0, NULL, 0xCC},
 		{"colonparsing", 0, NULL, '@'},
 		{"stateflags", 0, NULL, '%'},
 		{"minibar", 0, NULL, '_'},
@@ -1864,7 +1864,7 @@ int main(int argc, char **argv)
 	/* If setting the locale is successful and it uses UTF-8, we will
 	 * need to use the multibyte functions for text processing. */
 	if (setlocale(LC_ALL, "") && strcmp(nl_langinfo(CODESET), "UTF-8") == 0)
-		utf8_init();
+		using_utf8 = TRUE;
 #else
 	setlocale(LC_ALL, "");
 #endif
@@ -2128,6 +2128,9 @@ int main(int argc, char **argv)
 				break;
 #endif
 #ifndef NANO_TINY
+			case 0xCC:
+				SET(WHITESPACE_DISPLAY);
+				break;
 			case '@':
 				SET(COLON_PARSING);
 				break;
@@ -2150,6 +2153,10 @@ int main(int argc, char **argv)
 		}
 	}
 
+#ifndef NANO_TINY
+	set_up_sigwinch_handler();
+#endif
+
 	/* Curses needs TERM; if it is unset, try falling back to a VT220. */
 	if (getenv("TERM") == NULL)
 		putenv("TERM=vt220");
@@ -2370,7 +2377,7 @@ int main(int argc, char **argv)
 	/* If the whitespace option wasn't specified, set its default value. */
 	if (whitespace == NULL) {
 #ifdef ENABLE_UTF8
-		if (using_utf8()) {
+		if (using_utf8) {
 			/* A tab is shown as a Right-Pointing Double Angle Quotation Mark
 			 * (U+00BB), and a space as a Middle Dot (U+00B7). */
 			whitespace = copy_of("\xC2\xBB\xC2\xB7");
@@ -2431,8 +2438,7 @@ int main(int argc, char **argv)
 #endif
 	editwincols = COLS - sidebar;
 
-	/* Set up the signal handlers. */
-	signal_init();
+	set_up_signal_handlers();
 
 #ifdef ENABLE_MOUSE
 	/* Initialize mouse support. */
@@ -2576,11 +2582,21 @@ int main(int argc, char **argv)
 				continue;
 		}
 
+#ifdef ENABLE_HISTORIES
+		if (ISSET(POSITIONLOG) && openfile->filename[0] != '\0')
+			restore_cursor_position_if_any();
+#endif
+
 		/* If a position was given on the command line, go there. */
-		if (givenline != 0 || givencol != 0)
-			goto_line_and_column(givenline, givencol, FALSE, FALSE);
+		if (givenline != 0 || givencol != 0) {
+			openfile->current = openfile->filetop;
+			openfile->placewewant = 0;
+			goto_line_and_column(givenline, givencol, TRUE);
+		}
 #ifndef NANO_TINY
 		else if (searchstring != NULL) {
+			openfile->current = openfile->filetop;
+			openfile->current_x = 0;
 			if (ISSET(USE_REGEXP))
 				regexp_init(searchstring);
 			if (!findnextstr(searchstring, FALSE, JUSTFIND, NULL,
@@ -2596,14 +2612,6 @@ int main(int argc, char **argv)
 			last_search = searchstring;
 			searchstring = NULL;
 		}
-#endif
-#ifdef ENABLE_HISTORIES
-		else if (ISSET(POSITIONLOG) && openfile->filename[0] != '\0') {
-			ssize_t savedline, savedcol;
-			/* If edited before, restore the last cursor position. */
-			if (has_old_position(argv[optind - 1], &savedline, &savedcol))
-				goto_line_and_column(savedline, savedcol, FALSE, FALSE);
-		}
 #endif
 	}
 
@@ -2687,7 +2695,7 @@ int main(int argc, char **argv)
 #define byte(n)  (unsigned char)openfile->current->data[n]
 		/* Tell the user when the cursor sits on a BOM. */
 		if (openfile->current_x == 0 && byte(0) == 0xEF && byte(1) == 0xBB &&
-										byte(2) == 0xBF && using_utf8()) {
+										byte(2) == 0xBF && using_utf8) {
 			statusline(NOTICE, _("Byte Order Mark"));
 			set_blankdelay_to_one();
 		}
@@ -2713,6 +2721,7 @@ int main(int argc, char **argv)
 			wredrawln(midwin, editwinrows - 1, 1);
 #endif
 
+		final_status = 0;
 		errno = 0;
 		focusing = TRUE;
 
