@@ -14,7 +14,7 @@
  *   See the GNU General Public License for more details.                 *
  *                                                                        *
  *   You should have received a copy of the GNU General Public License    *
- *   along with this program.  If not, see http://www.gnu.org/licenses/.  *
+ *   along with this program.  If not, see https://gnu.org/licenses/.     *
  *                                                                        *
  **************************************************************************/
 
@@ -24,9 +24,11 @@
 
 #ifndef NANO_TINY
 extern volatile sig_atomic_t the_window_resized;
+extern volatile sig_atomic_t resized_for_browser;
 #endif
 
 extern bool on_a_vt;
+extern bool using_utf8;
 extern bool shifted_metas;
 
 extern bool meta_key;
@@ -40,6 +42,8 @@ extern bool report_size;
 extern bool ran_a_tool;
 extern char *foretext;
 
+extern int final_status;
+
 extern bool inhelp;
 extern char *title;
 
@@ -204,10 +208,6 @@ void to_last_file(void);
 #endif
 
 /* Most functions in chars.c. */
-#ifdef ENABLE_UTF8
-void utf8_init(void);
-bool using_utf8(void);
-#endif
 bool is_alpha_char(const char *c);
 bool is_blank_char(const char *c);
 bool is_cntrl_char(const char *c);
@@ -356,7 +356,7 @@ void load_history(void);
 void save_history(void);
 void load_poshistory(void);
 void update_poshistory(void);
-bool has_old_position(const char *file, ssize_t *line, ssize_t *column);
+void restore_cursor_position_if_any(void);
 #endif
 
 /* Most functions in move.c. */
@@ -485,9 +485,9 @@ void ask_for_and_do_replacements(void);
 #if !defined(NANO_TINY) || defined(ENABLE_SPELLER) || defined (ENABLE_LINTER) || defined (ENABLE_FORMATTER)
 void goto_line_posx(ssize_t line, size_t pos_x);
 #endif
-void goto_line_and_column(ssize_t line, ssize_t column, bool retain_answer,
-		bool interactive);
 void do_gotolinecolumn(void);
+void ask_for_line_and_column(char *provided);
+void goto_line_and_column(ssize_t line, ssize_t column, bool hugfloor);
 #ifndef NANO_TINY
 void do_find_bracket(void);
 void put_or_lift_anchor(void);
